@@ -1,7 +1,7 @@
 #!/bin/bash
 #
 #  Argus Client Support Software.  Tools to support tools for Argus data.
-#  Copyright (C) 2000-2008 QoSient, LLC.
+#  Copyright (C) 2000-2012 QoSient, LLC.
 #  All Rights Reserved
 #
 #  ragetcountrycodes.sh
@@ -23,4 +23,5 @@ wget --passive-ftp ftp://ftp.lacnic.net/pub/stats/lacnic/delegated-lacnic-latest
 wget --passive-ftp ftp://ftp.ripe.net/ripe/stats/delegated-ripencc-latest
 wget --passive-ftp ftp://ftp.apnic.net/pub/stats/iana/delegated-iana-latest
 
-fgrep ipv4 delegated*latest > delegated-ipv4-latest
+fgrep ipv4 delegated-[alr]*-latest delegated-iana-latest > delegated-ipv4-latest
+rm delegated-[alr]*-latest delegated-iana-latest
